pub type AggregateRouterFn<C> = dyn Fn(Arc<C>, Vec<AggregateSource>, CapabilitySource) -> Arc<Router<DirConnector>>;Expand description
Functions of this signature are used during sandbox to construct new aggregate routers. These aggregate routers synthesize together one capability from multiple sources.