pub trait LazyGet<T: CapabilityBound> {
// Required method
fn lazy_get<P>(
self,
path: P,
not_found_error: RoutingError,
) -> Arc<Router<T>> ⓘ
where P: IterablePath + Debug + 'static;
}Expand description
Implements the lazy_get function for Routable<Dictionary>.
Required Methods
Sourcefn lazy_get<P>(self, path: P, not_found_error: RoutingError) -> Arc<Router<T>> ⓘwhere
P: IterablePath + Debug + 'static,
fn lazy_get<P>(self, path: P, not_found_error: RoutingError) -> Arc<Router<T>> ⓘwhere
P: IterablePath + Debug + 'static,
Returns a router that requests a dictionary from the specified path relative to
the base routable or fails the request with not_found_error if the member is not
found.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".