ProgramOutputGenerator

Trait ProgramOutputGenerator 

pub trait ProgramOutputGenerator<C: ComponentInstanceInterface + 'static> {
    // Required methods
    fn new_program_dictionary_router(
        &self,
        component: WeakComponentInstanceInterface<C>,
        path: Path,
        capability: ComponentCapability,
    ) -> Arc<Router<Dictionary>> ;
    fn new_outgoing_dir_connector_router(
        &self,
        component: &Arc<C>,
        decl: &ComponentDecl,
        capability: &CapabilityDecl,
    ) -> Arc<Router<Connector>> ;
    fn new_outgoing_dir_dir_connector_router(
        &self,
        component: &Arc<C>,
        decl: &ComponentDecl,
        capability: &CapabilityDecl,
    ) -> Arc<Router<DirConnector>> ;
}

Required Methods

fn new_program_dictionary_router( &self, component: WeakComponentInstanceInterface<C>, path: Path, capability: ComponentCapability, ) -> Arc<Router<Dictionary>>

Get a router for Dictionary that forwards the request to a Router served at path in the program’s outgoing directory.

fn new_outgoing_dir_connector_router( &self, component: &Arc<C>, decl: &ComponentDecl, capability: &CapabilityDecl, ) -> Arc<Router<Connector>>

Get an outgoing directory router for capability that returns Connector. capability should be a type that maps to Connector.

fn new_outgoing_dir_dir_connector_router( &self, component: &Arc<C>, decl: &ComponentDecl, capability: &CapabilityDecl, ) -> Arc<Router<DirConnector>>

Get an outgoing directory router for capability that returns DirConnector. capability should be a type that maps to DirConnector.

Implementors