pub struct IsolatedStoragePath(pub PathBuf);Expand description
The isolated storage path in the backing directory of the providing component of a storage capability.
Tuple Fields
0: PathBufTrait Implementations
Sourceimpl Metadata<IsolatedStoragePath> for Dict
impl Metadata<IsolatedStoragePath> for Dict
Sourceconst KEY: &'static str = "isolated_storage_path"
const KEY: &'static str = "isolated_storage_path"
A key string used for setting and getting the metadata.
Sourcefn set_metadata(&self, value: IsolatedStoragePath)
fn set_metadata(&self, value: IsolatedStoragePath)
Infallibly assigns
value to self.Sourcefn get_metadata(&self) -> Option<IsolatedStoragePath>
fn get_metadata(&self) -> Option<IsolatedStoragePath>
Retrieves the subdir metadata from
self, if present.Auto Trait Implementations
impl Freeze for IsolatedStoragePath
impl RefUnwindSafe for IsolatedStoragePath
impl Send for IsolatedStoragePath
impl Sync for IsolatedStoragePath
impl Unpin for IsolatedStoragePath
impl UnwindSafe for IsolatedStoragePath