pub struct StorageSourceMoniker(pub Moniker);Expand description
The moniker of the component that provides a Storage porcelain capability.
Tuple Fields
0: MonikerTrait Implementations
Sourceimpl Metadata<StorageSourceMoniker> for Dict
impl Metadata<StorageSourceMoniker> for Dict
Sourceconst KEY: &'static str = "storage_source_moniker"
const KEY: &'static str = "storage_source_moniker"
A key string used for setting and getting the metadata.
Sourcefn set_metadata(&self, value: StorageSourceMoniker)
fn set_metadata(&self, value: StorageSourceMoniker)
Infallibly assigns
value to self.Sourcefn get_metadata(&self) -> Option<StorageSourceMoniker>
fn get_metadata(&self) -> Option<StorageSourceMoniker>
Retrieves the subdir metadata from
self, if present.Auto Trait Implementations
impl Freeze for StorageSourceMoniker
impl RefUnwindSafe for StorageSourceMoniker
impl Send for StorageSourceMoniker
impl Sync for StorageSourceMoniker
impl Unpin for StorageSourceMoniker
impl UnwindSafe for StorageSourceMoniker