pub struct StorageSubdir(pub RelativePath);Expand description
The subdirectory inside of the storage backing directory’s subdirectory to use, if any. The difference between this and SubDir is that a) the SubDir generically refers to the subdirectory of a directory capability, and b) the SubDir is appended to the IsolatedStoragePath first (which is a path into a backing directory), and component_manager will create the StorageSubdir if it doesn’t exist but won’t create SubDir. Accordingly, the complete path to a storage capability within the backing directory is {IsolatedStoragePath}/{SubDir}/{StorageSubdir}.
Tuple Fields
0: RelativePathTrait Implementations
Sourceimpl Metadata<StorageSubdir> for Dict
impl Metadata<StorageSubdir> for Dict
Sourceconst KEY: &'static str = "storage_subdir"
const KEY: &'static str = "storage_subdir"
A key string used for setting and getting the metadata.
Sourcefn set_metadata(&self, value: StorageSubdir)
fn set_metadata(&self, value: StorageSubdir)
Infallibly assigns
value to self.Sourcefn get_metadata(&self) -> Option<StorageSubdir>
fn get_metadata(&self) -> Option<StorageSubdir>
Retrieves the subdir metadata from
self, if present.Auto Trait Implementations
impl Freeze for StorageSubdir
impl RefUnwindSafe for StorageSubdir
impl Send for StorageSubdir
impl Sync for StorageSubdir
impl Unpin for StorageSubdir
impl UnwindSafe for StorageSubdir