pub struct ProgramInput { /* private fields */ }Expand description
All capabilities that are available to a component’s program.
Implementations
Sourceimpl ProgramInput
impl ProgramInput
pub fn new( namespace: Dictionary, runner: Option<Router<Connector>>, config: Dictionary, ) -> Self
Sourcepub fn namespace(&self) -> Dictionary
pub fn namespace(&self) -> Dictionary
All of the capabilities that appear in a program’s namespace.
Sourcepub fn numbered_handles(&self) -> Dictionary
pub fn numbered_handles(&self) -> Dictionary
All of the capabilities that appear in a program’s set of numbered handles.
Sourcepub fn runner(&self) -> Option<Router<Connector>>
pub fn runner(&self) -> Option<Router<Connector>>
A router for the runner that a component has used (if any).
Sourcepub fn config(&self) -> Dictionary
pub fn config(&self) -> Dictionary
All of the config capabilities that a program will use.