pub struct ComponentInput(/* private fields */);Expand description
Contains the capabilities component receives from its parent and environment. Stored as a Dictionary containing two nested Dictionarys for the parent and environment.
Implementations
Sourceimpl ComponentInput
impl ComponentInput
pub fn new(environment: ComponentEnvironment) -> Self
Sourcepub fn shallow_copy(&self) -> Self
pub fn shallow_copy(&self) -> Self
Creates a new ComponentInput with entries cloned from this ComponentInput.
This is a shallow copy. Values are cloned, not copied, so are new references to the same underlying data.
Sourcepub fn capabilities(&self) -> Dictionary
pub fn capabilities(&self) -> Dictionary
Returns the sub-dictionary containing capabilities routed by the component’s parent.
Sourcepub fn environment(&self) -> ComponentEnvironment
pub fn environment(&self) -> ComponentEnvironment
Returns the sub-dictionary containing capabilities routed by the component’s environment.
pub fn insert_capability( &self, path: &impl IterablePath, capability: Capability, ) -> Option<Capability>