ResolvedInstanceInterfaceExt

Trait ResolvedInstanceInterfaceExt 

pub trait ResolvedInstanceInterfaceExt: ResolvedInstanceInterface {
    // Provided method
    fn try_offer_source_exists(&self, source: &OfferSource) -> Option<bool> { ... }
}
An extension trait providing functionality for any model of a resolved component.

Provided Methods

fn try_offer_source_exists(&self, source: &OfferSource) -> Option<bool>

Returns true if the given offer source refers to a valid entity, e.g., a child that exists, a declared collection, etc. However, implementers are not required to retain their component decl, in which case they should return None if they lack sufficient information to determine if the offer source is a valid entity.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors