route_config_value

Function route_config_value 

pub async fn route_config_value<C>(
    use_config: &UseConfigurationDecl,
    component: &Arc<C>,
) -> Result<Option<ConfigValue>, RouterError>
where C: ComponentInstanceInterface + 'static,
Routes the config value referenced in use_config from component. Returns the default value if the capability is not available (i.e. routed from void), or if use_config has transitional availability and routing fails with an error that maps to NOT_FOUND.