debug_route_sandbox_path

Function debug_route_sandbox_path 

pub async fn debug_route_sandbox_path<C: ComponentInstanceInterface + 'static>(
    component: &Arc<C>,
    sandbox_path: impl Into<SandboxPath>,
) -> Result<CapabilitySource, RoutingError>
Calls route on the router at the given path within the component sandbox. Panics if the sandbox does not hold a router at that path.