pub struct IntermediateRouter { /* private fields */ }Expand description
A router that attempts to find a router to forward to in a source dictionary, validates (and potentially mutates) the route request, and then forwards the request to next router.
Implementations
Sourceimpl IntermediateRouter
impl IntermediateRouter
Sourcepub fn new(
source_dictionary: WeakDictionaryOrRouter,
source_path: RelativePath,
default_request: RouteRequest,
default_token: Arc<WeakInstanceToken>,
moniker: Moniker,
route_verb: RouteVerb,
source: Ref,
) -> Capability
pub fn new( source_dictionary: WeakDictionaryOrRouter, source_path: RelativePath, default_request: RouteRequest, default_token: Arc<WeakInstanceToken>, moniker: Moniker, route_verb: RouteVerb, source: Ref, ) -> Capability
Returns an IntermediateRouter wrapped in a Router type, with an appropriate type for the
default_request.build_type_name.