build_component_sandbox

Function build_component_sandbox 

pub fn build_component_sandbox<C: ComponentInstanceInterface + 'static>(
    component: &Arc<C>,
    child_component_output_dictionary_routers: HashMap<ChildName, Router<Dictionary>>,
    decl: &ComponentDecl,
    component_input: ComponentInput,
    program_output_dict: Dictionary,
    framework_router: Router<Dictionary>,
    capability_sourced_capabilities_dict: Dictionary,
    declared_dictionaries: Dictionary,
    error_reporter: impl ErrorReporter,
    aggregate_router_fn: &AggregateRouterFn<C>,
    event_stream_use_router_fn: &EventStreamUseRouterFn<C>,
) -> ComponentSandbox
Once a component has been resolved and its manifest becomes known, this function produces the various dicts the component needs based on the contents of its manifest.