pub trait WithPorcelain<T: CapabilityBound, R: ErrorReporter, C: ComponentInstanceInterface + 'static> {
// Required methods
fn with_porcelain_with_default(
self,
type_: CapabilityTypeName,
) -> PorcelainBuilder<T, R, C, true>;
fn with_porcelain_no_default(
self,
type_: CapabilityTypeName,
) -> PorcelainBuilder<T, R, C, false>;
}Expand description
See [WithPorcelain::with_porcelain] for documentation.
Required Methods
Sourcefn with_porcelain_with_default(
self,
type_: CapabilityTypeName,
) -> PorcelainBuilder<T, R, C, true>
fn with_porcelain_with_default( self, type_: CapabilityTypeName, ) -> PorcelainBuilder<T, R, C, true>
Returns a PorcelainBuilder you use to construct a new router with porcelain properties
that augments the self. See PorcelainBuilder for documentation of the supported
properties.
If a None request is passed into the built router, the router will supply a default
request based on the values passed to the builder.
Sourcefn with_porcelain_no_default(
self,
type_: CapabilityTypeName,
) -> PorcelainBuilder<T, R, C, false>
fn with_porcelain_no_default( self, type_: CapabilityTypeName, ) -> PorcelainBuilder<T, R, C, false>
Returns a PorcelainBuilder you use to construct a new router with porcelain properties
that augments the self. See PorcelainBuilder for documentation of the supported
properties.
If a None request is passed into the built router, the router will throw an InvalidArgs
error.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".