Enum routing::InterfaceError
[−]
[src]
pub enum InterfaceError {
NotConnected,
InvalidState,
ChannelRxError(RecvError),
EventSenderError(EventSenderError<MaidSafeEventCategory, Action>),
}The type of errors that can occur if routing is unable to handle a send request.
Variants
NotConnectedWe are not connected to the network.
InvalidStateWe are not in a state to handle the action.
ChannelRxError(RecvError)Error while trying to receive a message from a channel
EventSenderError(EventSenderError<MaidSafeEventCategory, Action>)Error while trying to transmit an event via a channel