Enum routing::Response [−][src]
pub enum Response {
GetAccountInfo {
res: Result<AccountInfo, ClientError>,
msg_id: MsgId,
},
PutIData {
res: Result<(), ClientError>,
msg_id: MsgId,
},
GetIData {
res: Result<ImmutableData, ClientError>,
msg_id: MsgId,
},
PutMData {
res: Result<(), ClientError>,
msg_id: MsgId,
},
GetMData {
res: Result<MutableData, ClientError>,
msg_id: MsgId,
},
GetMDataVersion {
res: Result<u64, ClientError>,
msg_id: MsgId,
},
GetMDataShell {
res: Result<MutableData, ClientError>,
msg_id: MsgId,
},
ListMDataEntries {
res: Result<BTreeMap<Vec<u8>, Value>, ClientError>,
msg_id: MsgId,
},
ListMDataKeys {
res: Result<BTreeSet<Vec<u8>>, ClientError>,
msg_id: MsgId,
},
ListMDataValues {
res: Result<Vec<Value>, ClientError>,
msg_id: MsgId,
},
GetMDataValue {
res: Result<Value, ClientError>,
msg_id: MsgId,
},
MutateMDataEntries {
res: Result<(), ClientError>,
msg_id: MsgId,
},
ListMDataPermissions {
res: Result<BTreeMap<User, PermissionSet>, ClientError>,
msg_id: MsgId,
},
ListMDataUserPermissions {
res: Result<PermissionSet, ClientError>,
msg_id: MsgId,
},
SetMDataUserPermissions {
res: Result<(), ClientError>,
msg_id: MsgId,
},
DelMDataUserPermissions {
res: Result<(), ClientError>,
msg_id: MsgId,
},
ChangeMDataOwner {
res: Result<(), ClientError>,
msg_id: MsgId,
},
ListAuthKeysAndVersion {
res: Result<(BTreeSet<PublicKey>, u64), ClientError>,
msg_id: MsgId,
},
InsAuthKey {
res: Result<(), ClientError>,
msg_id: MsgId,
},
DelAuthKey {
res: Result<(), ClientError>,
msg_id: MsgId,
},
}Response message types
Variants
GetAccountInfoReturns a success or failure status of account information retrieval.
Fields of GetAccountInfo
res: Result<AccountInfo, ClientError> | Result of fetching account info from the network. |
msg_id: MsgId | Unique message identifier |
PutIDataReturns a success or failure status of putting ImmutableData to the network.
Fields of PutIData
res: Result<(), ClientError> | Result of putting ImmutableData to the network. |
msg_id: MsgId | Unique message identifier |
GetIDataReturns a result of fetching ImmutableData from the network.
Fields of GetIData
res: Result<ImmutableData, ClientError> | Result of fetching ImmutableData from the network. |
msg_id: MsgId | Unique message identifier |
PutMDataReturns a success or failure status of putting MutableData to the network.
Fields of PutMData
res: Result<(), ClientError> | Result of putting MutableData to the network. |
msg_id: MsgId | Unique message identifier |
GetMDataReturns a result of fetching MutableData from the network.
Fields of GetMData
res: Result<MutableData, ClientError> | Result of fetching MutableData from the network. |
msg_id: MsgId | Unique message identifier |
GetMDataVersionReturns a current version of MutableData stored in the network.
Fields of GetMDataVersion
res: Result<u64, ClientError> | Result of getting a version of MutableData |
msg_id: MsgId | Unique message identifier |
GetMDataShellReturns the shell of MutableData (everything except the entries).
Fields of GetMDataShell
res: Result<MutableData, ClientError> | Result of getting the shell of MutableData. |
msg_id: MsgId | Unique message identifier |
ListMDataEntriesReturns a complete list of entries in MutableData or an error in case of failure.
Fields of ListMDataEntries
res: Result<BTreeMap<Vec<u8>, Value>, ClientError> | Result of getting a list of entries in MutableData |
msg_id: MsgId | Unique message identifier |
ListMDataKeysReturns a list of keys in MutableData or an error in case of failure.
Fields of ListMDataKeys
res: Result<BTreeSet<Vec<u8>>, ClientError> | Result of getting a list of keys in MutableData |
msg_id: MsgId | Unique message identifier |
ListMDataValuesReturns a list of values in MutableData or an error in case of failure.
Fields of ListMDataValues
res: Result<Vec<Value>, ClientError> | Result of getting a list of values in MutableData |
msg_id: MsgId | Unique message identifier |
GetMDataValueReturns a single entry from MutableData or an error in case of failure.
Fields of GetMDataValue
res: Result<Value, ClientError> | Result of getting a value from MutableData |
msg_id: MsgId | Unique message identifier |
MutateMDataEntriesReturns a success or failure status of mutating MutableData in the network.
Fields of MutateMDataEntries
res: Result<(), ClientError> | Result of mutating an entry in MutableData |
msg_id: MsgId | Unique message identifier |
ListMDataPermissionsReturns a complete list of MutableData permissions stored on the network or an error in case of failure.
Fields of ListMDataPermissions
res: Result<BTreeMap<User, PermissionSet>, ClientError> | Result of getting a list of permissions in MutableData |
msg_id: MsgId | Unique message identifier |
ListMDataUserPermissionsReturns a list of permissions for a particular User in MutableData or an error in case of failure.
Fields of ListMDataUserPermissions
res: Result<PermissionSet, ClientError> | Result of getting a list of user permissions in MutableData |
msg_id: MsgId | Unique message identifier |
SetMDataUserPermissionsReturns a success or failure status of setting permissions for a particular User in MutableData.
Fields of SetMDataUserPermissions
res: Result<(), ClientError> | Result of setting a list of user permissions in MutableData |
msg_id: MsgId | Unique message identifier |
DelMDataUserPermissionsReturns a success or failure status of deleting permissions for a particular User in MutableData.
Fields of DelMDataUserPermissions
res: Result<(), ClientError> | Result of deleting a list of user permissions in MutableData |
msg_id: MsgId | Unique message identifier |
ChangeMDataOwnerReturns a success or failure status of chaning an owner of MutableData.
Fields of ChangeMDataOwner
res: Result<(), ClientError> | Result of chaning an owner of MutableData |
msg_id: MsgId | Unique message identifier |
ListAuthKeysAndVersionReturns a list of authorised keys from MaidManager and the account version.
Fields of ListAuthKeysAndVersion
res: Result<(BTreeSet<PublicKey>, u64), ClientError> | Result of getting a list of authorised keys and version |
msg_id: MsgId | Unique message identifier |
InsAuthKeyReturns a success or failure status of inserting an authorised key into MaidManager.
Fields of InsAuthKey
res: Result<(), ClientError> | Result of inserting an authorised key |
msg_id: MsgId | Unique message identifier |
DelAuthKeyReturns a success or failure status of deleting an authorised key from MaidManager.
Fields of DelAuthKey
res: Result<(), ClientError> | Result of deleting an authorised key |
msg_id: MsgId | Unique message identifier |
Methods
impl Response[src]
impl Responsepub fn priority(&self) -> u8[src]
pub fn priority(&self) -> u8The priority Crust should send this message with.
pub fn message_id(&self) -> &MsgId[src]
pub fn message_id(&self) -> &MsgIdMessage ID getter.
pub fn is_cacheable(&self) -> bool[src]
pub fn is_cacheable(&self) -> boolIs this response cacheable?