pub async fn debug_route_sandbox_path<C: ComponentInstanceInterface + 'static>(
component: &Arc<C>,
sandbox_path: impl Into<SandboxPath>,
) -> Result<CapabilitySource, RoutingError>Expand description
Calls route on the router at the given path within the component sandbox. Panics if the
sandbox does not hold a router at that path.